/// <reference types="node" />
import { KeyboardBuilder, MessageContext, MessageEventContext } from "vk-io";
import * as Event from "events";
import { IPagesBuilderOptions, ISetDefaultButtonsOptions, IResetListenTimeoutOptions, ITrigger, TriggersMap, Page, PageSentMethod, PagesStorage } from "./interfaces";
export declare const pagesStorage: PagesStorage;
export declare class PagesBuilder extends Event.EventEmitter {
    _context: IPagesBuilderOptions["context"];
    readonly id: string;
    pages: Page[];
    protected header: string;
    protected footer: string;
    protected currentPage: number;
    protected infinityLoop: boolean;
    protected resetTimeout: boolean;
    protected pagesNumberFormat: string;
    sendMethod: string;
    protected listenTime: number;
    protected _listenTimeout: NodeJS.Timeout | null;
    protected listenUsers: number[];
    protected triggers: TriggersMap;
    sentContext: IPagesBuilderOptions["context"] | null;
    keyboard: KeyboardBuilder;
    constructor({ context }: IPagesBuilderOptions);
    setPages(pages: Page | Page[]): this;
    addPages(pages: Page | Page[]): this;
    setPage(pageNumber?: number): Promise<MessageContext>;
    autoResetTimeout(status?: boolean): this;
    setPagesNumberFormat(format?: string): this;
    setInfinityLoop(status?: boolean): this;
    setPagesHeader(header?: string): this;
    setPagesFooter(footer?: string): this;
    setSendMethod(method?: PageSentMethod): this;
    private getPage;
    setListenTime(time?: number): this;
    resetListenTimeout({ isFirstBuild }?: IResetListenTimeoutOptions): void;
    setListenUsers(users?: number | number[]): this;
    addListenUsers(users?: number | number[]): this;
    stopListen(): Promise<void>;
    setDefaultButtons({ buttons, type }?: ISetDefaultButtonsOptions): this;
    updateKeyboard(keyboard?: KeyboardBuilder | null): this;
    setTriggers(triggers: ITrigger | ITrigger[]): this;
    addTriggers(triggers: ITrigger | ITrigger[]): this;
    private executeTrigger;
    build(): Promise<this>;
    saveContext(): void;
    private cleanUpKeyboard;
    private executeAction;
    messageMiddleware(context: MessageContext | MessageEventContext): void;
}
